"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
var _vitest = require("vitest");
var _react = require("@testing-library/react");
var _userEvent = _interopRequireDefault(require("@testing-library/user-event"));
require("@testing-library/jest-dom");
var _runAxeCheck = require("@instructure/ui-axe-check/lib/runAxeCheck.js");
var _index = require("../index");
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _Portal, _Portal2, _Portal3, _Portal4, _div;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 *
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
describe(`<Portal />`, () => {
  it('should render', async () => {
    (0, _react.render)(_Portal || (_Portal = (0, _jsxRuntime.jsx)(_index.Portal, {
      open: true,
      children: "Hello World"
    })));
    const portal = _react.screen.getByText('Hello World');
    expect(portal).toBeInTheDocument();
  });
  it('should be accessible', async () => {
    const _render = (0, _react.render)(_Portal2 || (_Portal2 = (0, _jsxRuntime.jsx)(_index.Portal, {
        open: true,
        "data-testid": "portal",
        children: "Hello World"
      }))),
      container = _render.container;
    const axeCheck = await (0, _runAxeCheck.runAxeCheck)(container);
    expect(axeCheck).toBe(true);
  });
  it('should support onOpen prop', async () => {
    const onOpen = _vitest.vi.fn();
    (0, _react.render)((0, _jsxRuntime.jsx)(_index.Portal, {
      open: true,
      onOpen: onOpen,
      "data-testid": "portal",
      children: "Hello World"
    }));
    const portal = _react.screen.getByTestId('portal');
    expect(onOpen).toHaveBeenCalledWith(portal);
  });
  it('should support onClose prop', async () => {
    const onClose = _vitest.vi.fn();
    const _render2 = (0, _react.render)((0, _jsxRuntime.jsx)(_index.Portal, {
        open: true,
        onClose: onClose,
        children: "Hello World"
      })),
      rerender = _render2.rerender;
    expect(onClose).not.toHaveBeenCalled();
    rerender((0, _jsxRuntime.jsx)(_index.Portal, {
      open: false,
      onClose: onClose,
      children: "Hello World"
    }));
    expect(onClose).toHaveBeenCalled();
  });
  it('should add a dir attribute to the root DOM node', async () => {
    const onOpen = _vitest.vi.fn();
    (0, _react.render)((0, _jsxRuntime.jsx)(_index.Portal, {
      open: true,
      onOpen: onOpen,
      "data-testid": "portal",
      children: "Hello World"
    }));
    const portal = _react.screen.getByTestId('portal');
    expect(portal).toHaveAttribute('dir', 'ltr');
  });
  it('should not render if children are empty', async () => {
    (0, _react.render)(_Portal3 || (_Portal3 = (0, _jsxRuntime.jsx)(_index.Portal, {
      open: true,
      "data-testid": "portal"
    })));
    const portal = _react.screen.queryByTestId('portal');
    expect(portal).not.toBeInTheDocument();
  });
  describe('without a mountNode prop', () => {
    it('should render nothing when closed', async () => {
      (0, _react.render)(_Portal4 || (_Portal4 = (0, _jsxRuntime.jsx)(_index.Portal, {
        children: "Hello World"
      })));
      const portal = _react.screen.queryByTestId('portal');
      expect(portal).not.toBeInTheDocument();
    });
    it('should render children and have a node with a parent when open', async () => {
      const onKeyDown = _vitest.vi.fn();
      (0, _react.render)((0, _jsxRuntime.jsx)(_index.Portal, {
        open: true,
        "data-testid": "portal",
        children: (0, _jsxRuntime.jsx)("button", {
          onKeyDown: onKeyDown,
          children: "Hello World"
        })
      }));
      const portal = _react.screen.getByTestId('portal');
      const button = _react.screen.getByRole('button', {
        name: 'Hello World'
      });
      await _userEvent.default.type(button, '{enter}');
      await (0, _react.waitFor)(() => {
        expect(onKeyDown).toHaveBeenCalled();
      });
      expect(portal).toContainElement(button);
    });
  });
  describe('when a mountNode prop is provided', () => {
    it('should render nothing when closed', async () => {
      (0, _react.render)((0, _jsxRuntime.jsxs)("div", {
        children: [(0, _jsxRuntime.jsx)(_index.Portal, {
          mountNode: () => document.getElementById('portal-mount-node'),
          "data-testid": "portal",
          children: "Hello World"
        }), _div || (_div = (0, _jsxRuntime.jsx)("div", {
          id: "portal-mount-node"
        }))]
      }));
      const portal = _react.screen.queryByTestId('portal');
      expect(portal).not.toBeInTheDocument();
    });
    it('should render children and have a node with a parent when open', async () => {
      const mountNode = document.createElement('div');
      mountNode.setAttribute('id', 'portal-mount-node');
      document.body.appendChild(mountNode);
      (0, _react.render)((0, _jsxRuntime.jsx)(_index.Portal, {
        open: true,
        mountNode: mountNode,
        "data-testid": "portal",
        children: "Hello World"
      }));
      const portal = _react.screen.getByTestId('portal');
      expect(portal.parentElement).toBe(mountNode);
      expect(mountNode.parentElement).toBe(document.body);
    });
  });
});